"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assert = require("assert");
var swagger_service_1 = require("./swagger.service");
var swagger_definition_constant_1 = require("./swagger-definition.constant");
function build(buildDefinition) {
    assert.ok(buildDefinition, "Definition are required.");
    assert.ok(buildDefinition.info, "Informations are required. Base is { title: \"Title of my API\", version: \"1.0.0\"}");
    if (buildDefinition.basePath) {
        swagger_service_1.SwaggerService.getInstance().setBasePath(buildDefinition.basePath);
    }
    if (buildDefinition.openapi) {
        swagger_service_1.SwaggerService.getInstance().setOpenapi(buildDefinition.openapi);
    }
    if (buildDefinition.info) {
        swagger_service_1.SwaggerService.getInstance().setInfo(buildDefinition.info);
    }
    if (buildDefinition.schemes) {
        swagger_service_1.SwaggerService.getInstance().setSchemes(buildDefinition.schemes);
    }
    if (buildDefinition.produces) {
        swagger_service_1.SwaggerService.getInstance().setProduces(buildDefinition.produces);
    }
    if (buildDefinition.consumes) {
        swagger_service_1.SwaggerService.getInstance().setConsumes(buildDefinition.consumes);
    }
    if (buildDefinition.host) {
        swagger_service_1.SwaggerService.getInstance().setHost(buildDefinition.host);
    }
    if (buildDefinition.externalDocs) {
        swagger_service_1.SwaggerService.getInstance().setExternalDocs(buildDefinition.externalDocs);
    }
    if (buildDefinition.securityDefinitions) {
        swagger_service_1.SwaggerService.getInstance().addSecurityDefinitions(buildDefinition.securityDefinitions);
    }
    if (buildDefinition.models) {
        var definitions = {};
        for (var modelIndex in buildDefinition.models) {
            var model = buildDefinition.models[modelIndex];
            var newDefinition = {
                type: swagger_definition_constant_1.SwaggerDefinitionConstant.Model.Type.OBJECT,
                properties: {},
                required: []
            };
            for (var propertyIndex in model.properties) {
                var property = model.properties[propertyIndex];
                var newProperty = {
                    type: property.type
                };
                if (property.format) {
                    newProperty.format = property.format;
                }
                if (property.required) {
                    newDefinition.required.push(propertyIndex);
                }
                newDefinition.properties[propertyIndex] = newProperty;
            }
            definitions[modelIndex] = newDefinition;
        }
        swagger_service_1.SwaggerService.getInstance().setDefinitions(definitions);
    }
    swagger_service_1.SwaggerService.getInstance().buildSwagger();
}
exports.build = build;
